@@ -1,5 +1,5 @@
 import unittest
-from .axl import *
+from axl import *
 
 unittest.TestLoader.sortTestMethodsUsing = None
 ucm = axl(
@@ -336,9 +336,7 @@ class TestRead(unittest.TestCase):
 
     def _call_manager_group(self):
         self.assertIsInstance(
-            ucm.get_call_manager_group(
-                name="testcallmanagergroup",
-            )["return"],
+            ucm.get_call_manager_group(name="testcallmanagergroup",)["return"],
             dict,
             "Should return a dict",
         )
@@ -364,27 +362,21 @@ class TestRead(unittest.TestCase):
 
     def _route_group(self):
         self.assertIsInstance(
-            ucm.get_route_group(name="testrg",)["return"][
-                "routeGroup"
-            ]["uuid"],
+            ucm.get_route_group(name="testrg",)["return"]["routeGroup"]["uuid"],
             str,
             "Should return a str",
         )
 
     def _route_list(self):
         self.assertIsInstance(
-            ucm.get_route_list(name="testrl",)["return"][
-                "routeList"
-            ]["uuid"],
+            ucm.get_route_list(name="testrl",)["return"]["routeList"]["uuid"],
             str,
             "Should return a str",
         )
 
     def _route_pattern(self):
         self.assertIsInstance(
-            ucm.get_route_pattern(pattern="5555",)["return"][
-                "routePattern"
-            ]["uuid"],
+            ucm.get_route_pattern(pattern="5555",)["return"]["routePattern"]["uuid"],
             str,
             "Should return a str",
         )
@@ -401,8 +393,7 @@ class TestRead(unittest.TestCase):
     def _called_party_xform(self):
         self.assertIsInstance(
             ucm.get_called_party_xform(
-                pattern="5656",
-                routePartitionName="mypartition",
+                pattern="5656", routePartitionName="mypartition",
             )["return"]["calledPartyTransformationPattern"]["uuid"],
             str,
             "Should return a str",
@@ -411,8 +402,7 @@ class TestRead(unittest.TestCase):
     def _calling_party_xform(self):
         self.assertIsInstance(
             ucm.get_calling_party_xform(
-                pattern="6565",
-                routePartitionName="mypartition",
+                pattern="6565", routePartitionName="mypartition",
             )["return"]["callingPartyTransformationPattern"]["uuid"],
             str,
             "Should return a str",
@@ -420,18 +410,12 @@ class TestRead(unittest.TestCase):
 
     def _user(self):
         self.assertIsInstance(
-            ucm.get_user(
-                userid="testuser",
-            )["userid"],
-            str,
-            "Should be str",
+            ucm.get_user(userid="testuser",)["userid"], str, "Should be str"
         )
 
     def _sip_trunk(self):
         self.assertIsInstance(
-            ucm.get_sip_trunk(name="testtrunk",)["return"][
-                "sipTrunk"
-            ]["uuid"],
+            ucm.get_sip_trunk(name="testtrunk",)["return"]["sipTrunk"]["uuid"],
             str,
             "Should be str",
         )
@@ -796,9 +780,7 @@ class TestDelete(unittest.TestCase):
 
     def _calling_search_space(self):
         self.assertIsInstance(
-            ucm.delete_calling_search_space(
-                name="newcss",
-            )["return"],
+            ucm.delete_calling_search_space(name="newcss",)["return"],
             str,
             "Should return a str",
         )
@@ -829,9 +811,7 @@ class TestDelete(unittest.TestCase):
 
     def _call_manager_group(self):
         self.assertIsInstance(
-            ucm.delete_call_manager_group(
-                name="newcallmanagergroup",
-            )["return"],
+            ucm.delete_call_manager_group(name="newcallmanagergroup",)["return"],
             str,
             "Should return a str",
         )
@@ -859,11 +839,7 @@ class TestDelete(unittest.TestCase):
 
     def _route_group(self):
         self.assertIsInstance(
-            ucm.delete_route_group(
-                name="newrg",
-            )["return"],
-            str,
-            "Should return a str",
+            ucm.delete_route_group(name="newrg",)["return"], str, "Should return a str"
         )
 
     def _route_list(self):
@@ -907,20 +883,12 @@ class TestDelete(unittest.TestCase):
 
     def _user(self):
         self.assertIsInstance(
-            ucm.delete_user(
-                userid="testuser",
-            )["return"],
-            str,
-            "Should be str",
+            ucm.delete_user(userid="testuser",)["return"], str, "Should be str"
         )
 
     def _sip_trunk(self):
         self.assertIsInstance(
-            ucm.delete_sip_trunk(
-                name="newtrunk",
-            )["return"],
-            str,
-            "Should be str",
+            ucm.delete_sip_trunk(name="newtrunk",)["return"], str, "Should be str"
         )
 
     def _h323_gateway(self):
@@ -949,18 +917,14 @@ class TestDelete(unittest.TestCase):
 
     def _media_resource_group(self):
         self.assertIsInstance(
-            ucm.delete_media_resource_group(
-                name="newmrg",
-            )["return"],
+            ucm.delete_media_resource_group(name="newmrg",)["return"],
             str,
             "Should return a str",
         )
 
     def _media_resource_group_list(self):
         self.assertIsInstance(
-            ucm.delete_media_resource_group_list(
-                name="newmrgl",
-            )["return"],
+            ucm.delete_media_resource_group_list(name="newmrgl",)["return"],
             str,
             "Should return a str",
         )
